# NOTES ON BOOTSTRAPING PYTHON 3.x:
#
# Due to a dependency cycle between Python, rpm, pip, setuptools, wheel,
# and other packages, in order to rebase Python 3 one has to build in the
# following order:
#
# 1.  gdb 			%%bcond_with python
# 2.  gtk-doc			%%bcond_without bootstrap
# 3.  rpm-mageia-setup		%%bcond_without bootstrap
# 4.  python-rpm-generators	%%bcond_without bootstrap
# 5.  pyproject-rpm-macros      %%bcond_without bootstrap %%bcond_with tests
# 6.  python3 			(if python3 is build to core/udpates_testing there's no need to use %%bcond_with rpmwheels)
# 7.  python-rpm-macros 	(update __default_python3_version)
# 8.  python-setuptools		%%bcond_without bootstrap
# 9.  python-flit-core		%%bcond_without bootstrap
# 10. python-packaging		%%bcond_without bootstrap
# 11. python-wheel		%%bcond_without bootstrap
# 12. python-pip		%%bcond_with doc
# 13. python-rpm-generators	%%bcond_with bootstrap
# 15. python-setuptools		%%bcond_with bootstrap
# 16. python-wheel		%%bcond_with bootstrap
# 17. rpm
# 18. python-packaging		%%bcond_with bootstrap
# 18. pyproject-rpm-macros      %%bcond_with bootstrap
# 19. python-cython
# 20. python-numpy
# 21. boost
# 22. meson
# 23. ninja
# 24. x11-proto-devel
# 25. gdb			%%bcond_without python
# 26. python-coverage
# 28. python-yaml
# 29. python-markdown
# 30. python-markupsafe
# 31. python-beaker
# 32. python-typing-extensions
# 33. python-setuptools-scm
# 34. python-tomli
# 35. python-six
# 36. python-dateutil
# 37. python-pbr
# 38. python-linecache2
# 39. python-funcsigs
# 40. python-mock
# 41. python-mako
# 42. python-pathspec
# 43. python-pluggy
# 44. python-calver
# 45. python-trove-classifiers
# 46. python-hatchling
# 47. python-pygments
# 48. python-mypy-extensions
# 49. python-types-setuptools
# 50. python-mypy
# 51. python-charset-normalizer 	%%bcond_with test
# 52. python-idna
# 53. python-urllib3			%%bcond_with check
# 54. python-requests
# 55. python-chardet
# 56. python-docutils
# 57. gobject-introspection
# 58. python-enchant
# 59. file
# 60. rpmlint
# 61. rpm-mageia-setup			%%bcond_with bootstrap
# 62. gobject-introspection		(again with rpm-mageia-setup)
# 63. bm
# 64. python-httplib2
# 65. python-pyparsing
# 66. mgarepo

# Then the most important packages have to be built, starting from their
# various leaf dependencies recursively. After these have been built, a
# targeted rebuild should be requested for the rest.
#
# Currently these packages are recommended to have been built before a targeted
# rebuild after a python abi change:
# 1. python-pluggy
# 2. python-editables
# 3. python-pathspec
# 4. python-calver
# 5. python-trove-classifiers
# 6. python-hatchling
# 7. python-hatch-vcs
# 8. python-hatch-fancy-pypi-readme
# 9. python-attrs
# 10. python-py
# 11. python-iniconfig
# 12. python-pytest
#
# 13. python-sphinx-rtd-theme
# 14. python-sphinx-theme-alabaster
# 15. python-pytz
# 16. python-babel
# 17. python-imagesize
# 18. python-jinja2
# 19. python-snowballstemmer
# 20. python-sphinxcontrib-applehelp
# 21. python-sphinxcontrib-devhelp
# 22. python-sphinxcontrib-htmlhelp
# 23. python-sphinxcontrib-jsmath
# 24. python-sphinxcontrib-qthelp
# 25. python-sphinxcontrib-serializinghtml
# 26. python-sphinxcontrib-websupport
# 27. python-sphinx

# version
%global oversion 3.13.2
%global docver 3.13.2

%global pybasever %(echo %{oversion} | cut -d. -f1,2)
%global familyver %(echo %{oversion} | cut -d. -f1)

# pybasever without the dot:
%global pyshortver %(echo %{pybasever} | tr -d '.')

# comment out if not prerel
#global prerel rc1

# rel for bumping
%global rel 1

# filter out bogus requires on python(abi) = 3.6 for testsuite
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}^%{_libdir}/python%{pybasever}/test/test_importlib/data

# For bootstrapping python3.x to python3.y
%bcond_without bootstrap

%bcond_with dtrace

# Whether to use RPM build wheels from the python-{pip,setuptools}-wheel package
# Uses upstream bundled prebuilt wheels otherwise
%bcond_without rpmwheels
# If the rpmwheels condition is disabled, we use the bundled wheel packages
# from Python with the versions below.
# This needs to be manually updated when we update Python.
%global pip_version 24.3.1
%global setuptools_version 67.6.1
%global wheel_version 0.43.0

# Expensive optimizations (mainly, profile-guided optimizations)
%bcond_without optimizations

# Run the test suite in %%check
%bcond_without check

# Support for the GDB debugger
%bcond_with gdb_hooks

# The dbm.gnu module (key-value database)
%bcond_without gdbm

# Main interpreter loop optimization
%bcond_without computed_gotos

# Support for the Valgrind debugger/profiler
#%%ifarch %%{valgrind_arches}
%ifarch %ix86 x86_64 %arm64
%bcond_without valgrind
%else
%bcond_with valgrind
%endif

# =====================
# General global macros
# =====================

%global pylibdir %{_libdir}/python%{pybasever}
%global dynload_dir %{pylibdir}/lib-dynload

# ABIFLAGS, LDVERSION and SOABI are in the upstream configure.ac
# See PEP 3149 for some background: https://www.python.org/dev/peps/pep-3149/
%global ABIFLAGS_optimized %{nil}

%global LDVERSION_optimized %{pybasever}%{ABIFLAGS_optimized}

# We use the upstream arch triplets, we convert them from %%{_arch}-linux%%{_gnu}
%global platform_triplet %{expand:%(echo %{_arch}-linux%{_gnu} | sed -E \\
    -e 's/^arm(eb)?-linux-gnu(eabi)?$/arm\\1-linux-gnueabihf/')}

%global SOABI_optimized cpython-%{pyshortver}%{ABIFLAGS_optimized}-%{platform_triplet}

# All bytecode files are in a __pycache__ subdirectory, with a name
# reflecting the version of the bytecode.
# See PEP 3147: https://www.python.org/dev/peps/pep-3147/
# For example,
#   foo/bar.py
# has bytecode at:
#   foo/__pycache__/bar.cpython-%%{pyshortver}.pyc
#   foo/__pycache__/bar.cpython-%%{pyshortver}.opt-1.pyc
#   foo/__pycache__/bar.cpython-%%{pyshortver}.opt-2.pyc
%global bytecode_suffixes .cpython-%{pyshortver}*.pyc

# Disable automatic bytecompilation. The python3 binary is not yet be
# available in /usr/bin when Python is built. Also, the bytecompilation fails
# on files that test invalid syntax.
%global __brp_python_bytecompile %nil

%define lib_major       %{pybasever}
%define lib_name_orig   libpython%{familyver}
%define lib_name        %mklibname python %{lib_major}
%define develname       %mklibname python3 -d

Summary:        An interpreted, interactive object-oriented programming language
Name:           python3
Version:        %{oversion}
Release:        %mkrel %{?prerel:0.%prerel.}%{rel}
License:        Modified CNRI Open Source License
Group:          Development/Python

BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  blt
BuildRequires:  pkgconfig(bluez)
BuildRequires:  db-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(libnsl)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  mpdecimal-devel
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  libtirpc-devel
BuildRequires:  readline-devel
BuildRequires:  termcap-devel
BuildRequires:  tcl
BuildRequires:  pkgconfig(tcl)
BuildRequires:  tk
BuildRequires:  pkgconfig(tk)
BuildRequires:  autoconf
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(liblzma)
# uncomment once the emacs part no longer conflict with python 2.X
#BuildRequires: emacs
#BuildRequires: emacs-bin
%if %{with valgrind}
BuildRequires:  pkgconfig(valgrind)
%endif

%if %{with dtrace}
BuildRequires:  systemtap-sdt-devel
%endif

%if %{with rpmwheels}
BuildRequires:  python-setuptools-wheel >= %{setuptools_version}
BuildRequires:  python-pip-wheel >= %{pip_version}
%endif

%if %{without bootstrap}
# for make regen-all and distutils.tests.test_bdist_rpm
BuildRequires: python%{familyver}
# for proper automatic provides
BuildRequires: python3-rpm-generators
%endif

Source0:        https://www.python.org/ftp/python/%{oversion}/Python-%{oversion}%{?prerel}.tar.xz
Source1:        https://www.python.org/ftp/python/doc/%{docver}/python-%{docver}-docs-html.tar.bz2

# A simple script to check timestamps of bytecode files
# Run in check section with Python that is currently being built
# Originally written by bkabrda
Source8: check-pyc-timestamps.py

#
# Upstream patches
#

# (Patches taken from github.com/fedora-python/cpython)

# 00251 # 6a4ec74157aa01f1ada9f29f30a371cd9e5369e8
# Change user install location
#
# Set values of base and platbase in sysconfig from /usr
# to /usr/local when RPM build is not detected
# to make pip and similar tools install into separate location.
#
# Fedora Change: https://fedoraproject.org/wiki/Changes/Making_sudo_pip_safe
# Downstream only.
#
# We've tried to rework in Fedora 36/Python 3.10 to follow https://bugs.python.org/issue43976
# but we have identified serious problems with that approach,
# see https://bugzilla.redhat.com/2026979 or https://bugzilla.redhat.com/2097183
#
# pypa/distutils integration: https://github.com/pypa/distutils/pull/70
Patch251: 00251-change-user-install-location.patch

# 00371 # 0e580d52dd79a1973e9b363ad7487e7b9334f2a2
# Revert "bpo-1596321: Fix threading._shutdown() for the main thread (GH-28549) (GH-28589)"
#
# This reverts commit 38c67738c64304928c68d5c2bd78bbb01d979b94. It
# introduced regression causing FreeIPA's tests to fail.
#
# For more info see:
# https://bodhi.fedoraproject.org/updates/FEDORA-2021-e152ce5f31
# https://github.com/GrahamDumpleton/mod_wsgi/issues/730
#Patch371: 00371-revert-bpo-1596321-fix-threading-_shutdown-for-the-main-thread-gh-28549-gh-28589.patch

# 00445 # d1a32daddefad32ceb93155552858c0a0311b23e
# CVE-2024-12254: Ensure _SelectorSocketTransport.writelines pauses the protocol if needed
#
# Ensure _SelectorSocketTransport.writelines pauses the protocol if it reaches the high water mark as needed.
#
# Resolved upstream: https://github.com/python/cpython/issues/127655
#Patch445: 00445-cve-2024-12254-ensure-_selectorsockettransport-writelines-pauses-the-protocol-if-needed.patch

# (New patches go here ^^^)
#
# Mageia patches
#
Patch502:        python3-3.7.1-uid-gid-overflows.patch
Patch503:        python3-3.5.2-dont-raise-from-py_compile.patch
Patch506:        python3-3.6.2-python3-config-LIBPLUSED-cmp0004-error.patch

Provides:       python%{pybasever} = %{version}-%{release}
Provides:       python(abi) = %{pybasever}
Provides:       /usr/bin/python%{LDVERSION_optimized}
Provides:       /usr/bin/python%{pybasever}
Requires:       python-rpm-macros >= 3-8
Requires:       python3-rpm-macros >= 3-8

Requires:       %{lib_name} = %{version}-%{release}

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package -n     %{lib_name}
Summary:        Shared libraries for Python %{version}
Group:          System/Libraries
Requires:       %{lib_name}-stdlib = %{version}-%{release}

%description -n %{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n     %{lib_name}-stdlib
Summary:        Python %{version} standard library
Group:          Development/Python
%if %{with rpmwheels}
Requires:	python-setuptools-wheel
Requires:	python-pip-wheel
%else
Provides:	bundled(python3-pip) = %{pip_version}
Provides:	bundled(python3-setuptools) = %{setuptools_version}
%endif
Obsoletes:	python3-typing < %{version}-%{release}
Provides:	python%{python3_pkgversion}dist(typing) = %{version}
Provides:	python%{python3_version}dist(typing) = %{version}

%description -n %{lib_name}-stdlib
This package contains Python 3's standard library.
It is normally not used on its own, but as a dependency of Python %{version}.

%package -n     %{lib_name}-testsuite
Summary:        Testsuite for the Python %{version} standard library
Group:          Development/Python
Provides:       python3-testsuite = %{version}-%{release}
Requires:       %{lib_name}-stdlib = %{version}-%{release}
Requires:       %{lib_name} = %{version}-%{release}
Recommends:     tkinter3

%description -n %{lib_name}-testsuite
The complete testsuite for the Python standard library.
It is normally not used on its own, but as a dependency of Python %{version}.

%package -n     %{develname}
Summary:        The libraries and header files needed for Python development
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
Requires:       %{lib_name} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       python%{pybasever}-devel = %{version}-%{release}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}
Recommends:     %{lib_name}-testsuite
Recommends:     %{name}-docs

%description -n %{develname}
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{develname} if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package        docs
Summary:        Documentation for the Python programming language
Version:        %{oversion}
Requires:       %{name} >= %{version}
Requires:       xdg-utils
Group:          Development/Python
BuildArch:      noarch

%description    docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n     tkinter3
Summary:        A graphical user interface for the Python scripting language
Version:        %{oversion}
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
Requires:       tcl tk
Provides:       python3-tkinter

%description -n tkinter3
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%package -n     tkinter3-apps
Summary:        Various applications written using tkinter
Group:          Development/Python
Requires:       tkinter3

%description -n tkinter3-apps
Various applications written using tkinter

%prep
%autosetup -p1 -n Python-%{version}%{?prerel} -a1

%if %{with rpmwheels}
rm Lib/ensurepip/_bundled/pip-%{pip_version}-py3-none-any.whl
rm Lib/test/wheeldata/setuptools-%{setuptools_version}-py3-none-any.whl
rm Lib/test/wheeldata/wheel-%{wheel_version}-py3-none-any.whl
%endif

# Remove all exe files to ensure we are not shipping prebuilt binaries
# note that those are only used to create Microsoft Windows installers
# and that functionality is broken on Linux anyway
find -name '*.exe' -print -delete

# Remove all exe files to ensure we are not shipping prebuilt binaries
# note that those are only used to create Microsoft Windows installers
# and that functionality is broken on Linux anyway
find -name '*.exe' -print -delete

# Remove bundled libraries to ensure that we're using the system copy.
rm -r Modules/expat
rm -r Modules/_decimal/libmpdec

# Remove files that should be generated by the build
# (This is after patching, so that we can use patches directly from upstream)
rm configure pyconfig.h.in

# drop Autoconf version requirement
sed -i 's/^AC_PREREQ/dnl AC_PREREQ/' configure.ac

# fix doc index.html title
sed -i -e 's/\(<title>\)\([3-9]\(\.[0-9]\+\)\+\sDocumentation<\/title>\)/\1Python \2/' python-*-docs-html/index.html

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python3@'

%build
# The build process embeds version info extracted from the Git repository
# into the Py_GetBuildInfo and sys.version strings.
# Our Git repository is artificial, so we don't want that.
# Tell configure to not use git.
export HAS_GIT=not-found

autoreconf -vfi

# Get proper option names from bconds
%if %{with computed_gotos}
%global computed_gotos_flag yes
%else
%global computed_gotos_flag no
%endif

%if %{with optimizations}
%global optimizations_flag "--enable-optimizations"
%else
%global optimizations_flag "--disable-optimizations"
%endif

%global _disable_ld_no_undefined 1

export CFLAGS=" "
export CFLAGS_NODIST="%{build_cflags} -D_GNU_SOURCE -fPIC -fwrapv"
export CXXFLAGS=" "
export OPT=" "
export LINKCC="gcc"
export LDFLAGS=" "
export LDFLAGS_NODIST="%{build_ldflags} $(pkg-config --libs-only-L openssl)"

%configure \
  --with-platlibdir=%{_lib} \
  --enable-ipv6 \
  --enable-shared \
  --with-computed-gotos=%{computed_gotos_flag} \
  --with-dbmliborder=gdbm:ndbm:bdb \
  --with-system-expat \
  --with-system-ffi \
  --with-system-libmpdec \
  --enable-loadable-sqlite-extensions \
%if %{with dtrace}
  --with-dtrace \
%endif
  --with-lto \
  --with-ssl-default-suites=openssl \
  --without-static-libpython \
%if %{with rpmwheels}
  --with-wheel-pkg-dir=%{python_wheel_dir} \
%endif
%if %{with valgrind}
  --with-valgrind \
%endif
  --with-threads \
  --without-ensurepip \
  %{optimizations_flag}

%if %{without bootstrap}
  # Regenerate generated files (needs python3)
  %make_build regen-all PYTHON_FOR_REGEN="python%{pybasever}"
%endif

  # Invoke the build
  %make_build

%install

%if %{with gdb_hooks}
DirHoldingGdbPy=%{_usr}/lib/debug/%{_libdir}
mkdir -p %{buildroot}$DirHoldingGdbPy
%endif # with gdb_hooks

# When the actual %%{dynload_dir} exists (it does when python3.X is installed for regen-all)
# %%{buildroot}%%{dynload_dir} is not created by make install and the extension modules are missing
# Reported upstream as https://github.com/python/cpython/issues/98782
# A workaround is to create the directory before running make install
mkdir -p %{buildroot}%{dynload_dir}

%make_install

%if %{with gdb_hooks}
  # See comment on $DirHoldingGdbPy above
  PathOfGdbPy=$DirHoldingGdbPy/libpython%{pybasever}%{ABIFLAGS_optimized}-%{version}-%{release}.%{_arch}.debug-gdb.py
  cp Tools/gdb/libpython.py %{buildroot}$PathOfGdbPy
%endif # with gdb_hooks

# Install directories for additional packages
install -d -m 0755 %{buildroot}%{pylibdir}/site-packages/__pycache__
%if "%{_lib}" == "lib64"
# The 64-bit version needs to create "site-packages" in /usr/lib/ (for
# pure-Python modules) as well as in /usr/lib64/ (for packages with extension
# modules).
# Note that rpmlint will complain about hardcoded library path;
# this is intentional.
install -d -m 0755 %{buildroot}%{_prefix}/lib/python%{pybasever}/site-packages/__pycache__
%endif

# overwrite the copied binary with a link
pushd %{buildroot}%{_bindir}
#ln -sf python%{LDVERSION_optimized} python%{pybasever}
ln -sf python%{pybasever} python%{familyver}
popd

pushd %{buildroot}%{_libdir}
ln -sf $(ls libpython%{lib_major}*.so.*) libpython%{lib_major}.so
popd

# make python3 as default one
ln -s ./python%{pybasever} %{buildroot}%{_bindir}/python
ln -s ./pydoc%{pybasever} %{buildroot}%{_bindir}/pydoc
ln -s ./pygettext%{pybasever}.py %{buildroot}%{_bindir}/pygettext.py
ln -s ./msgfmt%{pybasever}.py %{buildroot}%{_bindir}/msgfmt.py
ln -s ./python%{pybasever}-config %{buildroot}%{_bindir}/python-config
ln -s ./python%{pybasever}.1 %{buildroot}%{_mandir}/man1/python.1
ln -s ./python-%{pybasever}.pc %{buildroot}%{_libdir}/pkgconfig/python.pc
ln -s ./python-%{pybasever}-embed.pc %{buildroot}%{_libdir}/pkgconfig/python-embed.pc

chmod 755 %{buildroot}%{_bindir}/idle3

%if %{with valgrind}
install Misc/valgrind-python.supp -D %{buildroot}%{_libdir}/valgrind/valgrind-python3.supp
%endif

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-tkinter3.desktop << EOF
[Desktop Entry]
Name=IDLE
Comment=IDE for Python3
Exec=%{_bindir}/idle3
Icon=development_environment_section
Terminal=false
Type=Application
Categories=Development;IDE;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop << EOF
[Desktop Entry]
Name=Python %{docver} documentation
Comment=Python %{docver} complete reference
Exec=%{_bindir}/xdg-open %{_docdir}/%{name}-docs/index.html
Icon=documentation_section
Terminal=false
Type=Application
Categories=Documentation;
EOF

# fix non real scripts
#chmod 644 %{buildroot}%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
find %{buildroot} -type f \( -name "test_binascii.py*" -o -name "test_grp.py*" -o -name "test_htmlparser.py*" \) -exec chmod 644 {} \;

# fix python library not stripped
chmod u+w %{buildroot}%{_libdir}/libpython%{lib_major}*.so.1.0 $RPM_BUILD_ROOT%{_libdir}/libpython3.so

# Make python3-devel multilib-ready
mv %{buildroot}%{_includedir}/python%{LDVERSION_optimized}/pyconfig.h \
   %{buildroot}%{_includedir}/python%{LDVERSION_optimized}/pyconfig-%{__isa_bits}.h
cat > %{buildroot}%{_includedir}/python%{LDVERSION_optimized}/pyconfig.h << EOF
#include <bits/wordsize.h>

#if __WORDSIZE == 32
#include "pyconfig-32.h"
#elif __WORDSIZE == 64
#include "pyconfig-64.h"
#else
#error "Unknown word size"
#endif
EOF

# Make sure distutils looks at the right pyconfig.h file
# See https://bugzilla.redhat.com/show_bug.cgi?id=201434
# Similar for sysconfig: sysconfig.get_config_h_filename tries to locate
# pyconfig.h so it can be parsed, and needs to do this at runtime in site.py
# when python starts up (see https://bugzilla.redhat.com/show_bug.cgi?id=653058)
#
# Split this out so it goes directly to the pyconfig-32.h/pyconfig-64.h
# variants:
##sed -i -e "s/'pyconfig.h'/'pyconfig-%{__isa_bits}.h'/" \
##  %{buildroot}%{pylibdir}/sysconfig.py

# Install i18n tools to bindir
# They are also in python2, so we version them
# https://bugzilla.redhat.com/show_bug.cgi?id=1571474
for tool in pygettext msgfmt; do
  cp -p Tools/i18n/${tool}.py %{buildroot}%{_bindir}/${tool}%{pybasever}.py
  ln -s ${tool}%{pybasever}.py %{buildroot}%{_bindir}/${tool}3.py
done

# Switch all shebangs to refer to the specific Python version.
# This currently only covers files matching ^[a-zA-Z0-9_]+\.py$,
# so handle files named using other naming scheme separately.
LD_LIBRARY_PATH=./ ./python \
  %{_rpmconfigdir}/redhat/pathfix.py \
  -i "%{_bindir}/python%{pybasever}" -pn \
  %{buildroot} \
  %{buildroot}%{_bindir}/*%{pybasever}.py \
  %{?with_gdb_hooks:%{buildroot}$DirHoldingGdbPy/*.py}

# Remove shebang lines from .py files that aren't executable, and
# remove executability from .py files that don't have a shebang line:
find %{buildroot} -name \*.py \
  \( \( \! -perm /u+x,g+x,o+x -exec sed -e '/^#!/Q 0' -e 'Q 1' {} \; \
  -print -exec sed -i '1d' {} \; \) -o \( \
  -perm /u+x,g+x,o+x ! -exec grep -m 1 -q '^#!' {} \; \
  -exec chmod a-x {} \; \) \)

# Get rid of DOS batch files:
find %{buildroot} -name \*.bat -exec rm {} \;

# Get rid of backup files:
find %{buildroot}/ -name "*~" -exec rm -f {} \;
find . -name "*~" -exec rm -f {} \;

# Do bytecompilation with the newly installed interpreter.
# This is similar to the script in macros.pybytecompile
# compile *.pyc
# Python CMD line options:
# -s - don't add user site directory to sys.path
# -B - don't write .pyc files on import
# compileall CMD line options:
# -f - force rebuild even if timestamps are up to date
# -o - optimization levels to run compilation with
# -s - part of path to left-strip from path to source file (buildroot)
# -p - path to add as prefix to path to source file (/ to make it absolute)
# --hardlink-dupes - hardlink different optimization level pycs together if identical (saves space)
# --invalidation-mode - we prefer the timestamp invalidation mode for performance reasons
# -x - skip test modules with SyntaxErrors (taken from the Makefile)
LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
%{buildroot}%{_bindir}/python%{pybasever} -s -B -m compileall \
-f %{_smp_mflags} -o 0 -o 1 -o 2 -s %{buildroot} -p / %{buildroot} --hardlink-dupes --invalidation-mode=timestamp \
-x 'bad_coding|badsyntax|site-packages|test/test_lib2to3/data'

# Turn this BRP off, it is done by compileall2 --hardlink-dupes above
%global __brp_python_hardlink %{nil}

# Since we have *.py files in bindir, this is created, but we don't want it
rm -rf %{buildroot}%{_bindir}/__pycache__

# Fixup permissions for shared libraries from non-standard 555 to standard 755:
find %{buildroot} -perm 555 -exec chmod 755 {} \;

# make man python3.Xm work https://bugzilla.redhat.com/show_bug.cgi?id=1612241
ln -s ./python%{pybasever}.1 %{buildroot}%{_mandir}/man1/python%{pybasever}m.1 

%if %{with check}
%check
# Exclude some tests that hangs on the BS
EXCLUDE="test_ssl test_socket test_epoll"
%if %{with bootstrap}
EXCLUDE="$EXCLUDE test_distutils"
%endif
%ifarch x86_64
EXCLUDE="$EXCLUDE test_faulthandler"
%endif
%ifarch %arm
EXCLUDE="$EXCLUDE test_float test_asyncio test_cmath"
%endif
# Local aarch64 tests succeeds, but fails on BS
%ifarch aarch64
EXCLUDE="$EXCLUDE test_posix test_asyncio test_openpty test_os test_pty test_readline"
%endif
# json test pass on local build but fail on BS
EXCLUDE="$EXCLUDE test_json"
# to investigate why it fails on local build
EXCLUDE="$EXCLUDE test_site"
# why this fails?
EXCLUDE="$EXCLUDE test_distutils test_peg_generator"
# failing with 3.8RC1:
EXCLUDE="$EXCLUDE test___all__ test_embed test_mmap test_os"
# failed because of expat, https://bugs.python.org/issue46794
EXCLUDE="$EXCLUDE test_xml_etree test_minidom"
# failing dtrace test
#EXCLUDE="$EXCLUDE test_dtrace"
# all tests must pass
# but we disable network on BS
WITHIN_PYTHON_RPM_BUILD= \
make test TESTOPTS="-wW --slowest -j0 -u none -x $EXCLUDE"
# consider use network on local build
#EXCLUDE=""
#WITHIN_PYTHON_RPM_BUILD= make test TESTOPTS="-u network -x $EXCLUDE"

%endif

%files
%{_bindir}/pydoc
%{_bindir}/pydoc%{familyver}
%{_bindir}/pydoc%{pybasever}
%{_bindir}/python
%{_bindir}/python%{familyver}
%{_bindir}/python%{pybasever}
%{_bindir}/python%{LDVERSION_optimized}
%{_mandir}/man*/*

%files -n %{lib_name}-stdlib
%license LICENSE
%doc README.rst
%{_includedir}/python%{LDVERSION_optimized}/pyconfig-%{__isa_bits}.h
%{pylibdir}/config-%{LDVERSION_optimized}-%{platform_triplet}/Makefile

%dir %{pylibdir}
%dir %{dynload_dir}

%license %{pylibdir}/LICENSE.txt

%dir %{pylibdir}/unittest/
%dir %{pylibdir}/unittest/__pycache__/
%{pylibdir}/unittest/*.py
%{pylibdir}/unittest/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/asyncio/
%dir %{pylibdir}/asyncio/__pycache__/
%{pylibdir}/asyncio/*.py
%{pylibdir}/asyncio/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/_pyrepl/
%dir %{pylibdir}/_pyrepl/__pycache__/
%{pylibdir}/_pyrepl/*.py
%{pylibdir}/_pyrepl/mypy.ini
%{pylibdir}/_pyrepl/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/pathlib/
%dir %{pylibdir}/pathlib/__pycache__/
%{pylibdir}/pathlib/*.py
%{pylibdir}/pathlib/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/sysconfig/
%dir %{pylibdir}/sysconfig/__pycache__/
%{pylibdir}/sysconfig/*.py
%{pylibdir}/sysconfig/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/venv/
%dir %{pylibdir}/venv/__pycache__/
%{pylibdir}/venv/*.py
%{pylibdir}/venv/__pycache__/*%{bytecode_suffixes}
%{pylibdir}/venv/scripts

%{pylibdir}/wsgiref
%{pylibdir}/xmlrpc

%dir %{pylibdir}/ensurepip/
%dir %{pylibdir}/ensurepip/__pycache__/
%{pylibdir}/ensurepip/*.py
%{pylibdir}/ensurepip/__pycache__/*%{bytecode_suffixes}

%if %{with rpmwheels}
%exclude %{pylibdir}/ensurepip/_bundled
%else
%dir %{pylibdir}/ensurepip/_bundled
%{pylibdir}/ensurepip/_bundled/pip-%{pip_version}-py3-none-any.whl
%endif

%dir %{pylibdir}/concurrent/
%dir %{pylibdir}/concurrent/__pycache__/
%{pylibdir}/concurrent/*.py
%{pylibdir}/concurrent/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/concurrent/futures/
%dir %{pylibdir}/concurrent/futures/__pycache__/
%{pylibdir}/concurrent/futures/*.py
%{pylibdir}/concurrent/futures/__pycache__/*%{bytecode_suffixes}

%{pylibdir}/pydoc_data

%{dynload_dir}/_blake2.%{SOABI_optimized}.so
%{dynload_dir}/_md5.%{SOABI_optimized}.so
%{dynload_dir}/_sha1.%{SOABI_optimized}.so
%{dynload_dir}/_sha2.%{SOABI_optimized}.so
%{dynload_dir}/_sha3.%{SOABI_optimized}.so

%{dynload_dir}/_asyncio.%{SOABI_optimized}.so
%{dynload_dir}/_bisect.%{SOABI_optimized}.so
%{dynload_dir}/_bz2.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_cn.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_hk.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_iso2022.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_jp.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_kr.%{SOABI_optimized}.so
%{dynload_dir}/_codecs_tw.%{SOABI_optimized}.so
%{dynload_dir}/_contextvars.%{SOABI_optimized}.so
%{dynload_dir}/_csv.%{SOABI_optimized}.so
%{dynload_dir}/_ctypes.%{SOABI_optimized}.so
%{dynload_dir}/_curses.%{SOABI_optimized}.so
%{dynload_dir}/_curses_panel.%{SOABI_optimized}.so
%{dynload_dir}/_dbm.%{SOABI_optimized}.so
%{dynload_dir}/_decimal.%{SOABI_optimized}.so
%{dynload_dir}/_elementtree.%{SOABI_optimized}.so
%if %{with gdbm}
%{dynload_dir}/_gdbm.%{SOABI_optimized}.so
%endif
%{dynload_dir}/_hashlib.%{SOABI_optimized}.so
%{dynload_dir}/_heapq.%{SOABI_optimized}.so
%{dynload_dir}/_interpchannels.%{SOABI_optimized}.so
%{dynload_dir}/_interpqueues.%{SOABI_optimized}.so
%{dynload_dir}/_interpreters.%{SOABI_optimized}.so
%{dynload_dir}/_json.%{SOABI_optimized}.so
%{dynload_dir}/_lsprof.%{SOABI_optimized}.so
%{dynload_dir}/_lzma.%{SOABI_optimized}.so
%{dynload_dir}/_multibytecodec.%{SOABI_optimized}.so
%{dynload_dir}/_multiprocessing.%{SOABI_optimized}.so
%{dynload_dir}/_opcode.%{SOABI_optimized}.so
%{dynload_dir}/_pickle.%{SOABI_optimized}.so
%{dynload_dir}/_posixsubprocess.%{SOABI_optimized}.so
%{dynload_dir}/_queue.%{SOABI_optimized}.so
%{dynload_dir}/_random.%{SOABI_optimized}.so
%{dynload_dir}/_socket.%{SOABI_optimized}.so
%{dynload_dir}/_sqlite3.%{SOABI_optimized}.so
%{dynload_dir}/_ssl.%{SOABI_optimized}.so
%{dynload_dir}/_statistics.%{SOABI_optimized}.so
%{dynload_dir}/_struct.%{SOABI_optimized}.so
%{dynload_dir}/_testclinic_limited.%{SOABI_optimized}.so
%{dynload_dir}/_testexternalinspection.%{SOABI_optimized}.so
%{dynload_dir}/_testlimitedcapi.%{SOABI_optimized}.so
%{dynload_dir}/array.%{SOABI_optimized}.so
%{dynload_dir}/binascii.%{SOABI_optimized}.so
%{dynload_dir}/cmath.%{SOABI_optimized}.so
%{dynload_dir}/_datetime.%{SOABI_optimized}.so
%{dynload_dir}/fcntl.%{SOABI_optimized}.so
%{dynload_dir}/grp.%{SOABI_optimized}.so
%{dynload_dir}/math.%{SOABI_optimized}.so
%{dynload_dir}/mmap.%{SOABI_optimized}.so
%{dynload_dir}/_posixshmem.%{SOABI_optimized}.so
%{dynload_dir}/pyexpat.%{SOABI_optimized}.so
%{dynload_dir}/readline.%{SOABI_optimized}.so
%{dynload_dir}/resource.%{SOABI_optimized}.so
%{dynload_dir}/select.%{SOABI_optimized}.so
%{dynload_dir}/syslog.%{SOABI_optimized}.so
%{dynload_dir}/termios.%{SOABI_optimized}.so
%{dynload_dir}/unicodedata.%{SOABI_optimized}.so
%{dynload_dir}/_uuid.%{SOABI_optimized}.so
%{dynload_dir}/xxlimited.%{SOABI_optimized}.so
%{dynload_dir}/xxlimited_35.%{SOABI_optimized}.so
%{dynload_dir}/xxsubtype.%{SOABI_optimized}.so
%{dynload_dir}/zlib.%{SOABI_optimized}.so
%{dynload_dir}/_zoneinfo.%{SOABI_optimized}.so

%dir %{pylibdir}/site-packages/
%dir %{pylibdir}/site-packages/__pycache__/
%{pylibdir}/site-packages/README.txt
%{pylibdir}/*.py
%dir %{pylibdir}/__pycache__/
%{pylibdir}/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/collections/
%dir %{pylibdir}/collections/__pycache__/
%{pylibdir}/collections/*.py
%{pylibdir}/collections/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/ctypes/
%dir %{pylibdir}/ctypes/__pycache__/
%{pylibdir}/ctypes/*.py
%{pylibdir}/ctypes/__pycache__/*%{bytecode_suffixes}
%{pylibdir}/ctypes/macholib

%{pylibdir}/curses

%dir %{pylibdir}/dbm/
%dir %{pylibdir}/dbm/__pycache__/
%{pylibdir}/dbm/*.py
%{pylibdir}/dbm/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/email/
%dir %{pylibdir}/email/__pycache__/
%{pylibdir}/email/*.py
%{pylibdir}/email/__pycache__/*%{bytecode_suffixes}
%{pylibdir}/email/mime
%doc %{pylibdir}/email/architecture.rst

%{pylibdir}/encodings

%{pylibdir}/html
%{pylibdir}/http

%dir %{pylibdir}/importlib/
%dir %{pylibdir}/importlib/__pycache__/
%{pylibdir}/importlib/*.py
%{pylibdir}/importlib/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/importlib/metadata/
%dir %{pylibdir}/importlib/metadata/__pycache__/
%{pylibdir}/importlib/metadata/*.py
%{pylibdir}/importlib/metadata/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/importlib/resources/
%dir %{pylibdir}/importlib/resources/__pycache__/
%{pylibdir}/importlib/resources/*.py
%{pylibdir}/importlib/resources/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/json/
%dir %{pylibdir}/json/__pycache__/
%{pylibdir}/json/*.py
%{pylibdir}/json/__pycache__/*%{bytecode_suffixes}

%{pylibdir}/logging
%{pylibdir}/multiprocessing

%dir %{pylibdir}/re/
%{pylibdir}/re/*.py
%{pylibdir}/re/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/sqlite3/
%dir %{pylibdir}/sqlite3/__pycache__/
%{pylibdir}/sqlite3/*.py
%{pylibdir}/sqlite3/__pycache__/*%{bytecode_suffixes}

%dir %{pylibdir}/tomllib/
%{pylibdir}/tomllib/*.py
%{pylibdir}/tomllib/__pycache__/*%{bytecode_suffixes}
%exclude %{pylibdir}/turtle.py
%exclude %{pylibdir}/__pycache__/turtle*%{bytecode_suffixes}

%{pylibdir}/urllib
%{pylibdir}/xml

%dir %{pylibdir}/zipfile/
%{pylibdir}/zipfile/*.py
%{pylibdir}/zipfile/__pycache__/*%{bytecode_suffixes}
%{pylibdir}/zipfile/_path/*.py
%{pylibdir}/zipfile/_path/__pycache__/*%{bytecode_suffixes}

%{pylibdir}/zoneinfo

%dir %{pylibdir}/__phello__
%{pylibdir}/__phello__/__init__.py
%{pylibdir}/__phello__/spam.py
%{pylibdir}/__phello__/__pycache__/*%{bytecode_suffixes}

%if "%{_lib}" == "lib64"
%attr(0755,root,root) %dir %{_prefix}/lib/python%{pybasever}
%attr(0755,root,root) %dir %{_prefix}/lib/python%{pybasever}/site-packages
%attr(0755,root,root) %dir %{_prefix}/lib/python%{pybasever}/site-packages/__pycache__/
%endif

%files -n %{lib_name}-testsuite
%{pylibdir}/test/
# These two are shipped in the main subpackage:
%exclude %{pylibdir}/test/test_support.py*
%exclude %{pylibdir}/test/__init__.py*
%{dynload_dir}/_ctypes_test.%{SOABI_optimized}.so
%{dynload_dir}/_testbuffer.%{SOABI_optimized}.so
%{dynload_dir}/_testcapi.%{SOABI_optimized}.so
%{dynload_dir}/_testclinic.%{SOABI_optimized}.so
%{dynload_dir}/_testimportmultiple.%{SOABI_optimized}.so
%{dynload_dir}/_testinternalcapi.%{SOABI_optimized}.so
%{dynload_dir}/_testmultiphase.%{SOABI_optimized}.so
%{dynload_dir}/_testsinglephase.%{SOABI_optimized}.so
%{dynload_dir}/_xxtestfuzz.%{SOABI_optimized}.so

%files -n %{lib_name}
%{_libdir}/libpython%{LDVERSION_optimized}.so.1*

%files -n %{develname}
%{_bindir}/pygettext.py
%{_bindir}/pygettext%{familyver}*.py

%{_bindir}/msgfmt.py
%{_bindir}/msgfmt%{familyver}*.py

%{_bindir}/python-config
%{_bindir}/python%{pybasever}-config
%{_bindir}/python%{LDVERSION_optimized}-config
%{_bindir}/python%{familyver}-config

%{_libdir}/libpython%{LDVERSION_optimized}.so
%{_libdir}/libpython%{pybasever}.so
%{_libdir}/libpython%{familyver}.so
%{_includedir}/python%{LDVERSION_optimized}
%exclude %{_includedir}/python%{LDVERSION_optimized}/pyconfig-%{__isa_bits}.h
%{pylibdir}/config-%{LDVERSION_optimized}-%{platform_triplet}
%{_libdir}/pkgconfig/python{,-embed}.pc
%{_libdir}/pkgconfig/python-%{LDVERSION_optimized}.pc
%{_libdir}/pkgconfig/python-%{pybasever}{,-embed}.pc
%{_libdir}/pkgconfig/python%{familyver}{,-embed}.pc

%exclude %{pylibdir}/config-%{LDVERSION_optimized}-%{platform_triplet}/Makefile
%if %{with valgrind}
%{_libdir}/valgrind/valgrind-python3.supp
%endif

%files docs
%doc python-*-docs-html/*
%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop

%files -n tkinter3
%{pylibdir}/idlelib
%{pylibdir}/tkinter
%{dynload_dir}/_tkinter.%{SOABI_optimized}.so
%{pylibdir}/turtle.py
%{pylibdir}/__pycache__/turtle*%{bytecode_suffixes}
%dir %{pylibdir}/turtledemo
%{pylibdir}/turtledemo/*.py
%{pylibdir}/turtledemo/*.cfg
%dir %{pylibdir}/turtledemo/__pycache__/
%{pylibdir}/turtledemo/__pycache__/*%{bytecode_suffixes}

%files -n tkinter3-apps
%{_bindir}/idle%{familyver}
%{_bindir}/idle%{pybasever}
%{_datadir}/applications/%{_real_vendor}-tkinter3.desktop

# We put the debug-gdb.py file inside /usr/lib/debug to avoid noise from ldconfig
# See https://bugzilla.redhat.com/show_bug.cgi?id=562980
#
# The /usr/lib/rpm/redhat/macros defines %%__debug_package to use
# debugfiles.list, and it appears that everything below /usr/lib/debug and
# (/usr/src/debug) gets added to this file (via LISTFILES) in
# /usr/lib/rpm/find-debuginfo.sh
#
# Hence by installing it below /usr/lib/debug we ensure it is added to the
# -debuginfo subpackage
# (if it doesn't, then the rpmbuild ought to fail since the debug-gdb.py
# payload file would be unpackaged)

# Workaround for https://bugzilla.redhat.com/show_bug.cgi?id=1476593
%undefine _debuginfo_subpackages


%changelog
* Wed Feb 19 2025 neoclust <neoclust> 3.13.2-1.mga10
+ Revision: 2149883
- New version 3.13.2

* Sat Dec 14 2024 wally <wally> 3.12.8-1.mga10
+ Revision: 2125076
- new version 3.12.8

* Sun Oct 20 2024 wally <wally> 3.12.7-1.mga10
+ Revision: 2109107
- new version 3.12.7 (docs are still 3.12.6)

* Sun Sep 15 2024 wally <wally> 3.12.6-1.mga10
+ Revision: 2096756
- new version 3.12.6

* Thu Aug 08 2024 wally <wally> 3.12.5-1.mga10
+ Revision: 2084271
- new version 3.12.5 (docs are still 3.12.4)

* Sun Jun 09 2024 wally <wally> 3.12.4-1.mga10
+ Revision: 2071927
- new version 3.12.4

* Mon Apr 08 2024 wally <wally> 3.12.2-5.mga10
+ Revision: 2056026
- build i686 again with -fcf-protection

* Sat Apr 06 2024 wally <wally> 3.12.2-4.mga10
+ Revision: 2055258
- rebuild for libnsl 2.0.1
- non-bootstrap build

* Sat Apr 06 2024 wally <wally> 3.12.2-3.mga10
+ Revision: 2055172
- build without -fcf-protection=full for now on i686
- bootstrap build for i686

* Sat Apr 06 2024 wally <wally> 3.12.2-2.mga10
+ Revision: 2055159
- rebuild for mpdecimal 4.0.0

* Tue Feb 20 2024 wally <wally> 3.12.2-1.mga10
+ Revision: 2042708
- new version 3.12.2

* Tue Dec 19 2023 wally <wally> 3.12.1-1.mga10
+ Revision: 2019283
- new version 3.12.1
- disable bootstrap build

* Thu Dec 07 2023 wally <wally> 3.12.0-3.mga10
+ Revision: 2014448
- fix arm32 arch triplet

* Thu Dec 07 2023 wally <wally> 3.12.0-2.mga10
+ Revision: 2014425
- disable valgrind support on arm32

* Thu Dec 07 2023 wally <wally> 3.12.0-1.mga10
+ Revision: 2014378
- new version 3.12
- sync with Fedora where appropriate
- build without -Wl,--no-undefined linker flag
- don't inject build time flags into flags used after build
- fix docs version in .desktop file

* Mon Sep 25 2023 wally <wally> 3.10.13-1.mga10
+ Revision: 1990861
- new version 3.10.13
- new doc version 3.10.12

* Sun Apr 16 2023 wally <wally> 3.10.11-1.mga9
+ Revision: 1953083
- new version 3.10.11

* Sun Feb 26 2023 wally <wally> 3.10.10-1.mga9
+ Revision: 1945511
- new version 3.10.10

* Sun Jan 01 2023 wally <wally> 3.10.9-3.mga9
+ Revision: 1928613
- fix python3dist(typing) provides versioning

* Sun Jan 01 2023 wally <wally> 3.10.9-2.mga9
+ Revision: 1928609
- provide python3dist(typing) with stdlib

* Sat Dec 10 2022 wally <wally> 3.10.9-1.mga9
+ Revision: 1920340
- new version 3.10.9
- add version info to docs .desktop name and comment

* Sun Oct 30 2022 wally <wally> 3.10.8-1.mga9
+ Revision: 1900304
- new version 3.10.8

* Tue Oct 04 2022 wally <wally> 3.10.7-4.mga9
+ Revision: 1894582
- sync patches with Fedora
- fix doc index page title

* Mon Oct 03 2022 wally <wally> 3.10.7-3.mga9
+ Revision: 1894398
- fix docs file permissions (mga#30929)

* Sat Oct 01 2022 wally <wally> 3.10.7-2.mga9
+ Revision: 1893664
- new version 3.10.7

* Tue Sep 06 2022 wally <wally> 3.10.6-2.mga9
+ Revision: 1884603
- provide python3.XX-devel with devel pkg (mga#30818)

* Wed Aug 10 2022 wally <wally> 3.10.6-1.mga9
+ Revision: 1876780
- new version 3.10.6
- add patch to fix CVE-2015-20107 (mga#30572)

* Thu Jun 09 2022 wally <wally> 3.10.5-1.mga9
+ Revision: 1863754
- new version 3.10.5

* Fri Apr 08 2022 wally <wally> 3.10.4-1.mga9
+ Revision: 1848134
- new version 3.10.4
+ papoteur <papoteur>
- Disabled failing tests using expat
+ pterjan <pterjan>
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tmb <tmb> 3.10.2-1.mga9
+ Revision: 1779219
- update to 3.10.2

* Sat Feb 05 2022 wally <wally> 3.10.1-2.mga9
+ Revision: 1771610
- fix armv7hl build

* Thu Feb 03 2022 wally <wally> 3.10.1-1.mga9
+ Revision: 1771203
- new version 3.10.1 (sync with Fedora where appropriate)

* Sat Nov 06 2021 wally <wally> 3.9.8-2.mga9
+ Revision: 1754183
- new version 3.9.8

* Sat Oct 02 2021 tmb <tmb> 3.9.7-2.mga9
+ Revision: 1747350
- rebuild for openssl 3.0.0

* Sun Sep 12 2021 wally <wally> 3.9.7-1.mga9
+ Revision: 1745356
- new version 3.9.7

* Thu Aug 05 2021 luigiwalser <luigiwalser> 3.9.6-2.mga9
+ Revision: 1739664
- rebuild for libffi

* Tue Jul 13 2021 wally <wally> 3.9.6-1.mga9
+ Revision: 1735928
- new version 3.9.6

* Sun May 30 2021 wally <wally> 3.9.5-1.mga9
+ Revision: 1728923
- new version 3.9.5
- sync patches with Fedora
- add provides for the bundled libmpdec

* Sat Apr 24 2021 tmb <tmb> 3.9.4-3.mga9
+ Revision: 1719242
- rebuild with gcc 11.1

* Wed Apr 14 2021 wally <wally> 3.9.4-2.mga9
+ Revision: 1715786
- don't leak '-Wl,--no-undefined' linker flag into distutils

* Mon Apr 05 2021 wally <wally> 3.9.4-1.mga9
+ Revision: 1713696
- new version 3.9.4

* Sat Mar 27 2021 wally <wally> 3.9.2-2.mga9
+ Revision: 1710935
- non-boostrap build

* Sun Mar 14 2021 wally <wally> 3.9.2-1.mga9
+ Revision: 1702503
- new version 3.9.2 (sync with Fedora where appropriate)

* Thu Feb 25 2021 wally <wally> 3.8.8-1.mga9
+ Revision: 1690226
- really update to new version 3.8.8 to fix CVE-2021-23336 (mga#28408)
- new version 3.8.8 to fix CVE-2021-23336 (mga#28408)

* Sun Jan 24 2021 neoclust <neoclust> 3.8.7-2.mga8
+ Revision: 1673182
- Add patch to fix CVE-2021-3177 (mga#28204)

* Tue Dec 22 2020 wally <wally> 3.8.7-1.mga8
+ Revision: 1662824
- new version 3.8.7

* Thu Dec 17 2020 wally <wally> 3.8.6-1.mga8
+ Revision: 1660232
- new version 3.8.6

* Thu Dec 17 2020 daviddavid <daviddavid> 3.8.5-3.mga8
+ Revision: 1660198
- fix again python2 conflicting version (mga#27857)

* Tue Dec 15 2020 tv <tv> 3.8.5-2.mga8
+ Revision: 1657581
- BR pkgconfig(libnsl)
- BR pkgconfig(libtirpc)

* Tue Jul 21 2020 wally <wally> 3.8.5-1.mga8
+ Revision: 1607731
- new version 3.8.5

* Fri Jul 17 2020 wally <wally> 3.8.4-1.mga8
+ Revision: 1606673
- new version 3.8.4
- build with dtrace

* Fri Jul 03 2020 daviddavid <daviddavid> 3.8.3-3.mga8
+ Revision: 1601544
- add upstream patch to fix CVE-2020-14422 (mga#26894)

* Fri Jun 19 2020 wally <wally> 3.8.3-2.mga8
+ Revision: 1597147
- add patch to fix sqlite3 deterministic test (bpo#40784)
+ ovitters <ovitters>
- rebuild for new ffi

* Sat May 23 2020 wally <wally> 3.8.3-1.mga8
+ Revision: 1587113
- new version 3.8.3

* Sat Feb 29 2020 wally <wally> 3.8.2-1.mga8
+ Revision: 1552063
- new version 3.8.2
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 3.8.1-2.mga8
+ Revision: 1476004
- rebuild for readline

* Mon Dec 23 2019 wally <wally> 3.8.1-1.mga8
+ Revision: 1469776
- new version 3.8.1
- build the core interpreter with -fno-semantic-interposition (from Fedora)
- move pathfix.py from devel to main pkg

* Sun Nov 24 2019 tv <tv> 3.8.0-4.mga8
+ Revision: 1462582
- relax conflicts against py2 again

* Sat Nov 23 2019 wally <wally> 3.8.0-3.mga8
+ Revision: 1462454
- make sure python2 conflicts will always work
+ daviddavid <daviddavid>
- fix python2 conflicting version

* Sat Nov 02 2019 wally <wally> 3.8.0-2.mga8
+ Revision: 1457330
- build with bluetooth support (enable socket.AF_BLUETOOTH)

* Tue Oct 15 2019 tv <tv> 3.8.0-1.mga8
+ Revision: 1453427
- 3.8 final

* Sat Oct 05 2019 tv <tv> 3.8.0-0.rc1.1.mga8
+ Revision: 1449385
- run tests in // & show the slowest ones
- temporary ignore some new tests that fails with 3.8rc1
+ daviddavid <daviddavid>
- new version 3.8.0rc1

* Fri Sep 13 2019 wally <wally> 3.8.0-0.b4.5.mga8
+ Revision: 1440482
- add patch to link C modules with libpython for now
- drop unnecessary *FLAGS

* Thu Sep 12 2019 tv <tv> 3.8.0-0.b4.4.mga8
+ Revision: 1440107
- exclude more tests on aarch64
- unset *FLAGS_NODIST like in python-3.7

* Sat Sep 07 2019 wally <wally> 3.8.0-0.b4.3.mga8
+ Revision: 1438104
- filter out bogus testsuite requires

* Thu Sep 05 2019 wally <wally> 3.8.0-0.b4.2.mga8
+ Revision: 1437660
- skip test_distutils test for now
- be more stricter with python-rpm-macros requires
- disable bootstrapping

* Tue Sep 03 2019 wally <wally> 3.8.0-0.b4.1.mga8
+ Revision: 1436696
- new version 3.8b4
- sync .spec and patches with Fedora where appropriate

* Sat Aug 31 2019 wally <wally> 3.7.4-3.mga8
+ Revision: 1435999
- build without GDB debugger for now
- switch python3 to default python interpreter

* Wed Jul 17 2019 daviddavid <daviddavid> 3.7.4-2.mga8
+ Revision: 1422118
- add a virtual provides on python3-testsuite for lib(64)python3.7-testsuite

* Tue Jul 09 2019 daviddavid <daviddavid> 3.7.4-1.mga8
+ Revision: 1419782
- new version: 3.7.4

* Thu Apr 04 2019 daviddavid <daviddavid> 3.7.3-1.mga7
+ Revision: 1385719
- new version: 3.7.3, fixes CVE-2019-5010 and CVE-2019-9636 (mga#23664)

* Mon Jan 28 2019 luigiwalser <luigiwalser> 3.7.2-2.mga7
+ Revision: 1361535
- add patch from fedora to fix CVE-2019-5010

* Sat Jan 05 2019 wally <wally> 3.7.2-1.mga7
+ Revision: 1349923
- new version 3.7.2 (update docs also)
- drop upstreamed patches P313 and P315
- rediff P111 and P189

* Fri Jan 04 2019 wally <wally> 3.7.1-1.mga7
+ Revision: 1349148
- skip test_asyncio on aarch64 for now
- skip test_posix on aarch64 for now
- new version 3.7.1
- sync patches with Fedora
- sync .spec with Fedora where appropriate

* Thu Dec 27 2018 wally <wally> 3.6.7-3.mga7
+ Revision: 1345300
- build using -fwrapv (and update other flags also)

* Wed Nov 28 2018 tv <tv> 3.6.7-2.mga7
+ Revision: 1336457
- recommends instead of requires pip & setuptools (mga#23894)

* Thu Nov 22 2018 philippem <philippem> 3.6.7-1.mga7
+ Revision: 1333360
- update to 3.6.7

* Wed Sep 26 2018 tv <tv> 3.6.6-4.mga7
+ Revision: 1306465
- make clear which patches are coming from FC (easier to sync)
- reenable rewheel

* Mon Sep 24 2018 tv <tv> 3.6.6-2.mga7
+ Revision: 1303668
- fix pathfix call
- updated docs

* Mon Sep 24 2018 tv <tv> 3.6.6-1.mga7
+ Revision: 1303612
- unset with_rewheel
- new release

* Mon Sep 24 2018 tv <tv> 3.6.5-6.mga7
+ Revision: 1303574
- 3.6.5's pathfix doesn't know yet about -n
- Fix pathfix.py shebang

* Mon Sep 24 2018 tv <tv> 3.6.5-5.mga7
+ Revision: 1303467
- Fix multiprocessing regression on newer glibcs (rhbz#1569933)
- use new way to handle byte compilation
- do not abort build on bytecompile issues
- package pathfix.py for llvm & clang
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Jun 17 2018 luigiwalser <luigiwalser> 3.6.5-3.mga7
+ Revision: 1237491
- rebuild for gdbm

* Wed Jun 06 2018 pterjan <pterjan> 3.6.5-2.mga7
+ Revision: 1234900
- Don't force exact setuptools version, this prevents from building the package

* Thu Apr 12 2018 philippem <philippem> 3.6.5-1.mga7
+ Revision: 1217880
- update to 3.6.5

* Sun Mar 11 2018 philippem <philippem> 3.6.4-1.mga7
+ Revision: 1208180
- update to 3.6.4

* Fri Feb 23 2018 kekepower <kekepower> 3.6.2-6.mga7
+ Revision: 1204288
+ rebuild (emptylog)

* Fri Feb 23 2018 kekepower <kekepower> 3.6.2-5.mga7
+ Revision: 1204287
- Added a patch for an error with python3-config --ldflags
- See https://bugs.python.org/issue32914

* Tue Jan 02 2018 wally <wally> 3.6.2-4.mga7
+ Revision: 1189463
- rebuild for new readline
+ philippem <philippem>
- add instruction on bootstraping

* Thu Aug 03 2017 guillomovitch <guillomovitch> 3.6.2-3.mga7
+ Revision: 1134244
- rebuild for latest openssl

* Sun Jul 30 2017 philippem <philippem> 3.6.2-2.mga7
+ Revision: 1132870
- add patch for libffi
- force pip and setuptools version
- build with rewheel

* Fri Jul 28 2017 philippem <philippem> 3.6.2-1.mga7
+ Revision: 1132067
- First step to upgrade to 3.6.2
- revert to r1083841, keep pip 8.0.2
- update pip to 8.0.3

* Sat Jan 28 2017 philippem <philippem> 3.5.3-1.mga6
+ Revision: 1083841
- update to 3.5.3

* Wed Sep 07 2016 neoclust <neoclust> 3.5.2-4.mga6
+ Revision: 1050299
- Submit to release

* Sat Aug 13 2016 philippem <philippem> 3.5.2-3.mga6
+ Revision: 1046401
- fix CVE-2016-1000110

* Wed Jul 06 2016 tmb <tmb> 3.5.2-2.mga6
+ Revision: 1039105
- submit to release

* Sun Jul 03 2016 philippem <philippem> 3.5.2-1.mga6
+ Revision: 1038565
- update to 3.5.2

* Tue Jun 21 2016 philippem <philippem> 3.5.1-15.mga6
+ Revision: 1037113
- improve patch for zipimporter (mga#18691)

* Sun Jun 19 2016 philippem <philippem> 3.5.1-14.mga6
+ Revision: 1036801
- update conflicts, add conflicts for testsuite and devel
- fix CVE-2016-0772 mga#18691

* Sun Jun 12 2016 philippem <philippem> 3.5.1-12.mga6
+ Revision: 1021228
- fix heap overflow in zipimporter module mga#18691

* Mon Jun 06 2016 tv <tv> 3.5.1-11.mga6
+ Revision: 1020343
- unbloat installation:
  o remove recommends on tkinter-apps
  o move recommends on python-doc in devel package

* Sun Jun 05 2016 philippem <philippem> 3.5.1-10.mga6
+ Revision: 1020248
- fix armv7hl build, remove hf from arm triplet (change patch from Fedora)

* Sat Jun 04 2016 philippem <philippem> 3.5.1-9.mga6
+ Revision: 1020239
- fix armv7hl build, remove hf from arm triplet (patch from Fedora)

* Fri Jun 03 2016 philippem <philippem> 3.5.1-8.mga6
+ Revision: 1020190
- remove idlelib from stdlib, it is in tkinter3
- split in sub packages (mga#18561)
+ ovitters <ovitters>
- undo accidental changelog inclusion
- reenable tests

* Thu Mar 03 2016 umeabot <umeabot> 3.5.1-7.mga6
+ Revision: 983963
- Rebuild for openssl

* Tue Mar 01 2016 ovitters <ovitters> 3.5.1-6.mga6
+ Revision: 981719
- rebuild for new openssl

* Sat Feb 27 2016 philippem <philippem> 3.5.1-5.mga6
+ Revision: 980083
- remove macros now in python-rpm-macros
- remove wrong patch add-mga-support.patch
- remove macros now in python-rpm-macros
- fix test on pip version
+ tv <tv>
- patch 200: make platform supports Mageia
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 09 2015 philippem <philippem> 3.5.1-2.mga6
+ Revision: 909004
- exclude test_asyncio test_cmath on arm

* Tue Dec 08 2015 philippem <philippem> 3.5.1-1.mga6
+ Revision: 908868
- update to 3.5.1

* Tue Oct 13 2015 philippem <philippem> 3.5.0-5.mga6
+ Revision: 890256
- fix upstream issue 25150, mga#16951

* Sat Oct 03 2015 tv <tv> 3.5.0-4.mga6
+ Revision: 885886
- rebuild for new tcl

* Wed Sep 23 2015 philippem <philippem> 3.5.0-3.mga6
+ Revision: 882408
- add rewheel-module.patch
- update to 3.5.0, with wheel, remove obsolete %%py3ver and %%py3_ver macros

* Tue Sep 22 2015 philippem <philippem> 3.5.0-2.mga6
+ Revision: 882274
- json test pass on local build but fail on BS
- update to 3.5.0, first step

* Sun Sep 06 2015 philippem <philippem> 3.4.3-8.mga6
+ Revision: 873282
- add new macros

* Sun Aug 30 2015 philippem <philippem> 3.4.3-7.mga6
+ Revision: 871175
- Use _sysconfigdata.py in distutils to initialize distutils, mga#16570

* Thu Aug 13 2015 philippem <philippem> 3.4.3-6.mga6
+ Revision: 864562
- something is broken with distutils and multiarch, so we add the include

* Thu Aug 13 2015 philippem <philippem> 3.4.3-5.mga6
+ Revision: 864274
- Remove the wrong distutils-pyconfig.patch

* Thu Aug 13 2015 philippem <philippem> 3.4.3-4.mga6
+ Revision: 864190
- patch distutils to find pyconfig, mga#16570

* Sun Jul 19 2015 philippem <philippem> 3.4.3-3.mga6
+ Revision: 855506
- fix shebangs

* Wed Jul 01 2015 philippem <philippem> 3.4.3-2.mga6
+ Revision: 849412
- disable test_socket on the BS
- add missing requires fix mga#16048

* Thu Feb 26 2015 philippem <philippem> 3.4.3-1.mga5
+ Revision: 817018
- update to 3.4.3, fix mga#14780

* Mon Oct 27 2014 philippem <philippem> 3.4.2-1.mga5
+ Revision: 793977
- Update to 3.4.2
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.4.1-5.mga5
+ Revision: 728013
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Jun 28 2014 philippem <philippem> 3.4.1-3.mga5
+ Revision: 640729
- fix CVE-2014-4650 mga#15588)

* Sat May 24 2014 philippem <philippem> 3.4.1-2.mga5
+ Revision: 625308
- Build with rewheel

* Fri May 23 2014 philippem <philippem> 3.4.1-1.mga5
+ Revision: 625082
- update to 3.4.1

* Sat May 10 2014 philippem <philippem> 3.3.4-2.mga5
+ Revision: 621846
- fix CVE-2014-2667 mga#13305

* Sun Feb 16 2014 philippem <philippem> 3.3.4-1.mga5
+ Revision: 592814
- fix patch 00173 (missing backslash)
+ tv <tv>
- fix test suite
- new version
- rediff patches
- drop merged patches

* Sat Feb 15 2014 philippem <philippem> 3.3.2-14.mga5
+ Revision: 592080
-fix buffer overflow CVE-2014-1912 with upstream patch

* Tue Nov 26 2013 philippem <philippem> 3.3.2-13.mga4
+ Revision: 553625
- apply the patch to follow RFC 6125 in ssl.match_hostname() (mga#11785)

* Tue Nov 26 2013 philippem <philippem> 3.3.2-12.mga4
+ Revision: 553620
- change behavior of ssl.match_hostname() to follow RFC 6125 (fix mga#11785)

* Mon Nov 11 2013 philippem <philippem> 3.3.2-11.mga4
+ Revision: 550479
- remove no needed files that may conflict with python2

* Mon Oct 21 2013 umeabot <umeabot> 3.3.2-10.mga4
+ Revision: 539348
- Mageia 4 Mass Rebuild
+ philippem <philippem>
- provide tkinker (module) as python3-tkinter to follow the policy

* Thu Sep 26 2013 philippem <philippem> 3.3.2-8.mga4
+ Revision: 486633
- Add a RPM macro py_byte_compile to enable specfiles to selectively byte-compile individual files and paths with different Python runtimes as necessary

* Thu Sep 26 2013 fwang <fwang> 3.3.2-7.mga4
+ Revision: 486489
- drop unneeded provides

* Wed Sep 25 2013 philippem <philippem> 3.3.2-6.mga4
+ Revision: 486299
+ rebuild (emptylog)

* Wed Sep 25 2013 fwang <fwang> 3.3.2-5.mga4
+ Revision: 485860
- skip test_urllib2_localnet also
+ philippem <philippem>
- remove PYTHONDONTWRITEBYTECODE=1 fix mga#3348
- profile.d files as configfile noreplace fix mga#10758

* Tue Aug 13 2013 philippem <philippem> 3.3.2-4.mga4
+ Revision: 465986
- disable parallel build
+ oden <oden>
- P184: security fix for CVE-2013-4073 (upstream)

* Tue Jun 25 2013 philippem <philippem> 3.3.2-3.mga4
+ Revision: 446647
- add py3dir macro
+ shlomif <shlomif>
- Fix MGA#9395
- Convert inconsistent indentation to spaces only.
- Remove unused docs archive

* Fri May 31 2013 tv <tv> 3.3.2-2.mga4
+ Revision: 433777
- update docs
- patch 183: fix CVE-2013-2099 (ssl.match_hostname DOS)

* Fri May 31 2013 tv <tv> 3.3.2-1.mga4
+ Revision: 433688
- disable some failling tests
- add patches from FC in order to fix gdb tests
- new release
- drop merged patch

* Tue Mar 19 2013 fwang <fwang> 3.3.0-4.mga3
+ Revision: 404044
- add patch from opensuse to fix test

* Sun Jan 13 2013 umeabot <umeabot> 3.3.0-3.mga3
+ Revision: 379744
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 28 2012 rtp <rtp> 3.3.0-2.mga3
+ Revision: 335888
- fix tests

* Sat Sep 29 2012 fwang <fwang> 3.3.0-1.mga3
+ Revision: 300282
- add more provides to binary
- update file list
- update file list
- more linkage fix
- skip some failed tests
- drop -l
- add more linkage fix
- new version 3.3.0

* Wed Aug 08 2012 luigiwalser <luigiwalser> 3.2.3-5.mga3
+ Revision: 280050
- add patch from OpenSuSE to fix CVE-2012-2135 (patch 3)
- add upstream patch adding tests to testsuite associated w/CVE (patch 4)

* Mon Jul 30 2012 tv <tv> 3.2.3-4.mga3
+ Revision: 276244
- rebuild for db-5.3

* Thu Jul 05 2012 wally <wally> 3.2.3-3.mga3
+ Revision: 268245
- fix curses module build (mga#6702)

* Tue Jul 03 2012 kamil <kamil> 3.2.3-2.mga3
+ Revision: 266996
- add P2 fdr-lib64-fix-for-test_install.patch
- sync P1 with Fedora and fix x86_64 bugs (mga#6664)

* Sat Apr 14 2012 fwang <fwang> 3.2.3-1.mga2
+ Revision: 230764
- update lib64 patch
- new version 3.2.3

* Mon Feb 20 2012 guillomovitch <guillomovitch> 3.2.2-3.mga2
+ Revision: 211298
- don't hardcode pyconfig.h location in lib64 path
- ship pyconfig.h in main package, not just multiarch wrapper
- spec cleanup

* Mon Dec 05 2011 fwang <fwang> 3.2.2-2.mga2
+ Revision: 176932
- add upstream patch to recognize gdbm 1.9 magic value
- build with gdbm
- rebuild for new gdbm

* Mon Sep 05 2011 fwang <fwang> 3.2.2-1.mga2
+ Revision: 138550
- new version 3.2.2

* Fri Sep 02 2011 tv <tv> 3.2.1-2.mga2
+ Revision: 137805
- make the huge doc subpackage be noarch

* Tue Jul 12 2011 fwang <fwang> 3.2.1-1.mga2
+ Revision: 122718
- use ln -sf always
- update file list
- really rediff lib64 patch
- rediff lib64 patch
- new version 3.2.1

* Sat Jul 02 2011 fwang <fwang> 3.2-6.mga2
+ Revision: 117326
- rebuild for new tcl

* Tue Jun 28 2011 fwang <fwang> 3.2-5.mga2
+ Revision: 115157
- add provides for binary

* Tue Jun 07 2011 dmorgan <dmorgan> 3.2-4.mga2
+ Revision: 101527
- imported package python3


* Mon May 02 2011 Funda Wang <fwang@mandriva.org> 3.2-4mdv2011.0
+ Revision: 661885
- update file list
- update file list
- move makefile and pyconfig into main
- more lib64 patch

* Sun Apr 24 2011 Funda Wang <fwang@mandriva.org> 3.2-3
+ Revision: 658191
- rename devel name

* Sat Apr 23 2011 Funda Wang <fwang@mandriva.org> 3.2-2
+ Revision: 656821
- build with wide-unicode

* Sat Apr 23 2011 Funda Wang <fwang@mandriva.org> 3.2-1
+ Revision: 656799
- update file list
- use space
- clean spec file
- rediff lib64 patch
- rediff lib64 patch
- new version 3.2

* Mon Nov 01 2010 Funda Wang <fwang@mandriva.org> 3.1.2-4mdv2011.0
+ Revision: 591289
- move macro into main package

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 3.1.2-3mdv2011.0
+ Revision: 591178
- fix module link
- drop obsoletes swtich
- add python3.macros to ease python3 packaging
- tweak binary name in scripts

* Sat Oct 30 2010 Anssi Hannula <anssi@mandriva.org> 3.1.2-2mdv2011.0
+ Revision: 590324
- add provides on python(abi) (as per Fedora), for automated python
  module dependencies on python version
- workaround rpm issue in filelist to fix build

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - backport disable pymalloc on valgrind from svn

* Thu Apr 22 2010 Michael Scherer <misc@mandriva.org> 3.1.2-1mdv2010.1
+ Revision: 537934
- update to 3.1.2
- fix cruft in lib64 patch

* Sat Apr 17 2010 Michael Scherer <misc@mandriva.org> 3.1.1-9mdv2010.1
+ Revision: 536061
- rebuild for new rpm-mandriva-setup, to fix installation ( #58793 )

* Thu Apr 08 2010 Michael Scherer <misc@mandriva.org> 3.1.1-8mdv2010.1
+ Revision: 533004
- rebuild for new rpm-mandriva-setup

* Thu Mar 25 2010 Michael Scherer <misc@mandriva.org> 3.1.1-7mdv2010.1
+ Revision: 527485
- rebuild to fix upgrade ( due to python-base removal )

* Fri Feb 05 2010 Michael Scherer <misc@mandriva.org> 3.1.1-6mdv2010.1
+ Revision: 501053
- remove BR on emacs as we do not build emacs extension for the moment ( conflict with python 2.x )
- do not add a BuildRequires on emacs, uneeded for the moment
- remove old comment
- use README.mdv, not mdk
- do not obsolete package that does exist
- remove redundant BuildRequires
- do not provides python-base, this should be removed from the distro,
  as there is no subpackage named like this ( more ever, this is likely to
  be a wrong provides, as python 3 is too different from python 2 )

* Sun Jan 17 2010 Michael Scherer <misc@mandriva.org> 3.1.1-5mdv2010.1
+ Revision: 492597
- fix linking to ncursesw, to fix canto segfaulting

* Sun Jan 03 2010 Michael Scherer <misc@mandriva.org> 3.1.1-4mdv2010.1
+ Revision: 486004
- move tkinter module to proper subpackage
- add patch to fix bug 56260, as python do not detect tcl/tk 8.6, by porting the patch from
  regular python package to python 3

* Wed Nov 11 2009 Michael Scherer <misc@mandriva.org> 3.1.1-3mdv2010.1
+ Revision: 464473
- fix file conflict for tkinteer desktop file, as pointed by laurent pointal on bug  55507

* Tue Aug 18 2009 Eugeni Dodonov <eugeni@mandriva.com> 3.1.1-2mdv2010.0
+ Revision: 417514
- updated to 3.1.1

* Fri Jul 24 2009 Bogdano Arendartchuk <bogdano@mandriva.com> 3.1-2mdv2010.0
+ Revision: 399512
- adapted the lib64 patch to py3k

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Packaged python3.
    - Created package structure for python3.

